# ADS1015

Texas Instruments Analog-Digital Converter

- Device address 73
- Address type 7-bit
- Little Endian

### Addr 0 16-bytes Read-only | # ADC Value ## Conversion register contains the result of the last conversion
### Addr 1 16-bytes | # Set the channel to read ## This sets the channel for reading analog voltage ### [14:12] | 3-bytes Inaccessible | # Setup programmable gain ## This sets the programmable gain for reading analog voltage ### [11:9] | 3-bytes Write-only | # Set the operating mode ## This bit controls the operating mode ### [8:8] | 1-byte Write-only | # Setup sample rate for reading analog voltage ## This sets the samples-per-second value ### [7:5] | 3-bytes Write-only

## Functions

- analog.read - Reads the analog voltage in Volts